@@ -15,18 +15,14 @@ from ....utils.functions import raise_exception
 from ... import AgentCheck
 from .connection import Connection
 from .counter import PerfObject
-from .refresh import WindowsPerformanceObjectRefresher
 
 
 class PerfCountersBaseCheck(AgentCheck):
-    OBJECT_REFRESHER = WindowsPerformanceObjectRefresher()
     SERVICE_CHECK_HEALTH = 'windows.perf.health'
 
     def __init__(self, name, init_config, instances):
         super().__init__(name, init_config, instances)
 
-        self.interval = self.OBJECT_REFRESHER.interval
-
         self.enable_health_service_check = is_affirmative(self.instance.get('enable_health_service_check', True))
 
         # Prevent overriding an integration's defined namespace
@@ -43,9 +39,6 @@ class PerfCountersBaseCheck(AgentCheck):
 
         self.check_initializations.append(self.create_connection)
 
-        if self.interval > 0:
-            self.check_initializations.append(self.setup_refresher)
-
         self.check_initializations.append(self.configure_perf_objects)
 
     def check(self, _):
@@ -128,13 +121,6 @@ class PerfCountersBaseCheck(AgentCheck):
         self.log.debug('Setting `server` to `%s`', self._connection.server)
         self._connection.connect()
 
-    def setup_refresher(self):
-        self.OBJECT_REFRESHER.add_server(self._connection.server)
-
-        # Expected for multiple calls
-        with suppress(RuntimeError):
-            self.OBJECT_REFRESHER.start()
-
     def get_perf_object(self, connection, object_name, object_config, use_localized_counters, tags):
         return PerfObject(self, connection, object_name, object_config, use_localized_counters, tags)
 
@@ -159,8 +145,6 @@ class PerfCountersBaseCheck(AgentCheck):
             self.__NAMESPACE__ = old_namespace
 
     def cancel(self):
-        self.OBJECT_REFRESHER.remove_server(self._connection.server)
-
         for perf_object in self.perf_objects:
             with suppress(Exception):
                 perf_object.clear()
