@@ -10,6 +10,8 @@ COUNTER_VALUE_FORMAT = win32pdh.PDH_FMT_DOUBLE | 0x00008000
 # Success (positive values)
 PDH_CSTATUS_VALID_DATA = 0
 PDH_CSTATUS_NEW_DATA = 1
+
 # Errors (negative values)
 PDH_MORE_DATA = -2147481646  # 0x800007D2
-PDH_NO_DATA = -2147481643  # 0x800007D5
+PDH_INVALID_DATA = -1073738810  # 0xc0000bc6
+PDH_CSTATUS_INVALID_DATA = -1073738822  # 0xc0000bba
